[![version](https://img.shields.io/badge/version-2.0.0-blue.svg)](./CHANGELOG.md)
[![license](https://img.shields.io/badge/license-MIT-blue.svg)](./LICENSE)
[![Build Status](https://travis-ci.com/elliptical/clot.svg)](https://travis-ci.com/elliptical/clot)
[![Coverage Status](https://coveralls.io/repos/github/elliptical/clot/badge.svg?branch=develop)](https://coveralls.io/github/elliptical/clot?branch=develop)

# clot
Essentially, this is a playground for my tcm package.

On top of that, I'll get some experience with Python descriptors and tkinter package.
